]> sigrok.org Git - libsigrok.git/blobdiff - log.c
detect version 1.x of libftdi library
[libsigrok.git] / log.c
diff --git a/log.c b/log.c
index 6ebede70418f6f56dd6d53576d24957089482299..db16c30dabb00597d438307196a19a310b01104f 100644 (file)
--- a/log.c
+++ b/log.c
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the libsigrok project.
  *
  * Copyright (C) 2011-2012 Uwe Hermann <uwe@hermann-uwe.de>
  *
@@ -21,6 +21,9 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include "libsigrok.h"
+/** @cond PRIVATE */
+#define NO_LOG_WRAPPERS
+/** @endcond */
 #include "libsigrok-internal.h"
 
 /**
  */
 
 /* Currently selected libsigrok loglevel. Default: SR_LOG_WARN. */
-static int sr_loglevel = SR_LOG_WARN; /* Show errors+warnings per default. */
+static int cur_loglevel = SR_LOG_WARN; /* Show errors+warnings per default. */
 
 /* Function prototype. */
 static int sr_logv(void *cb_data, int loglevel, const char *format,
                   va_list args);
 
 /* Pointer to the currently selected log callback. Default: sr_logv(). */
-static sr_log_callback_t sr_log_callback = sr_logv;
+static sr_log_callback sr_log_cb = sr_logv;
 
 /*
  * Pointer to private data that can be passed to the log callback.
  * This can be used (for example) by C++ GUIs to pass a "this" pointer.
  */
-static void *sr_log_callback_data = NULL;
+static void *sr_log_cb_data = NULL;
 
 /* Log domain (a short string that is used as prefix for all messages). */
 /** @cond PRIVATE */
@@ -74,6 +77,8 @@ static char sr_log_domain[LOGDOMAIN_MAXLEN + 1] = LOGDOMAIN_DEFAULT;
  *                 SR_LOG_INFO, SR_LOG_DBG, or SR_LOG_SPEW).
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid loglevel.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_loglevel_set(int loglevel)
 {
@@ -82,7 +87,7 @@ SR_API int sr_log_loglevel_set(int loglevel)
                return SR_ERR_ARG;
        }
 
-       sr_loglevel = loglevel;
+       cur_loglevel = loglevel;
 
        sr_dbg("libsigrok loglevel set to %d.", loglevel);
 
@@ -93,10 +98,12 @@ SR_API int sr_log_loglevel_set(int loglevel)
  * Get the libsigrok loglevel.
  *
  * @return The currently configured libsigrok loglevel.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_loglevel_get(void)
 {
-       return sr_loglevel;
+       return cur_loglevel;
 }
 
 /**
@@ -112,6 +119,8 @@ SR_API int sr_log_loglevel_get(void)
  *                  the caller does not need to keep it around.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid logdomain.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_logdomain_set(const char *logdomain)
 {
@@ -134,6 +143,8 @@ SR_API int sr_log_logdomain_set(const char *logdomain)
  * @return A copy of the currently configured libsigrok logdomain
  *         string. The caller is responsible for g_free()ing the string when
  *         it is no longer needed.
+ *
+ * @since 0.1.0
  */
 SR_API char *sr_log_logdomain_get(void)
 {
@@ -152,8 +163,10 @@ SR_API char *sr_log_logdomain_get(void)
  *                to be NULL if the caller doesn't need/want to pass any data.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
+ *
+ * @since 0.3.0
  */
-SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
+SR_API int sr_log_callback_set(sr_log_callback cb, void *cb_data)
 {
        if (!cb) {
                sr_err("log: %s: cb was NULL", __func__);
@@ -162,8 +175,8 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
 
        /* Note: 'cb_data' is allowed to be NULL. */
 
-       sr_log_callback = cb;
-       sr_log_callback_data = cb_data;
+       sr_log_cb = cb;
+       sr_log_cb_data = cb_data;
 
        return SR_OK;
 }
@@ -171,9 +184,11 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
 /**
  * Set the libsigrok log callback to the default built-in one.
  *
* Additionally, the internal 'sr_log_callback_data' pointer is set to NULL.
  *
  * @return SR_OK upon success, a negative error code otherwise.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_log_callback_set_default(void)
 {
@@ -181,8 +196,8 @@ SR_API int sr_log_callback_set_default(void)
         * Note: No log output in this function, as it should safely work
         * even if the currently set log callback is buggy/broken.
         */
-       sr_log_callback = sr_logv;
-       sr_log_callback_data = NULL;
+       sr_log_cb = sr_logv;
+       sr_log_cb_data = NULL;
 
        return SR_OK;
 }
@@ -195,7 +210,7 @@ static int sr_logv(void *cb_data, int loglevel, const char *format, va_list args
        (void)cb_data;
 
        /* Only output messages of at least the selected loglevel(s). */
-       if (loglevel > sr_loglevel)
+       if (loglevel > cur_loglevel)
                return SR_OK; /* TODO? */
 
        if (sr_log_domain[0] != '\0')
@@ -213,7 +228,7 @@ SR_PRIV int sr_log(int loglevel, const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, loglevel, format, args);
+       ret = sr_log_cb(sr_log_cb_data, loglevel, format, args);
        va_end(args);
 
        return ret;
@@ -226,7 +241,7 @@ SR_PRIV int sr_spew(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_SPEW, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_SPEW, format, args);
        va_end(args);
 
        return ret;
@@ -239,7 +254,7 @@ SR_PRIV int sr_dbg(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_DBG, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_DBG, format, args);
        va_end(args);
 
        return ret;
@@ -252,7 +267,7 @@ SR_PRIV int sr_info(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_INFO, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_INFO, format, args);
        va_end(args);
 
        return ret;
@@ -265,7 +280,7 @@ SR_PRIV int sr_warn(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_WARN, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_WARN, format, args);
        va_end(args);
 
        return ret;
@@ -278,7 +293,7 @@ SR_PRIV int sr_err(const char *format, ...)
        va_list args;
 
        va_start(args, format);
-       ret = sr_log_callback(sr_log_callback_data, SR_LOG_ERR, format, args);
+       ret = sr_log_cb(sr_log_cb_data, SR_LOG_ERR, format, args);
        va_end(args);
 
        return ret;
@@ -171,9 +184,11 @@ SR_API int sr_log_callback_set(sr_log_callback_t cb, void *cb_data)
  * Set the libsigrok log callback to the default built-in one.
  *
- * Additionally, the internal 'sr_log_callback_data' pointer is set to NULL.
+ * Additionally, the internal 'sr_log_cb_data' pointer is set to NULL.
  *
  * @return SR_OK upon success, a negative error code otherwise.